#!/usr/bin/python3

# ==================================================boilerplate»=====
# *Tonto2* is a rewrite of *tonto* v1.2.
# 
# Copyright 2006—2023 by Chuck Rhode.
# 
# See LICENSE.txt for your rights.
# =================================================«boilerplate======

def run_tonto2():
    import tonto2.tonto2 as tonto2
    tonto2.entry_point()

def run_tonto2_conv_adr():
    import tonto2.tonto2_conv_adr as tonto2_conv_adr
    tonto2_conv_adr.entry_point()

def run_tonto2_conv_cal():
    import tonto2.tonto2_conv_cal as tonto2_conv_cal
    tonto2_conv_cal.entry_point()

# fin!
